<?php

  /**
   * Theme definitions
   */
  

 $theme_version_from_stylesheet = wp_get_theme();

   if( !defined('MT_THEME_URL') ) {
        define('MT_THEME_URL', get_template_directory_uri() );
    }

    if( !defined('MT_THEME_VERSION') ) { 
      define('MT_THEME_VERSION', $theme_version_from_stylesheet->get('Version'));
    }

    if( !defined('MT_THEME_NAME') ) {
      define('MT_THEME_NAME', $theme_version_from_stylesheet->get('Name') );
    }

    if ( !defined('MT_FRAMEWORK_VERSION') ){
        define('MT_FRAMEWORK_VERSION', '1.0.2');
    }


if ( ! function_exists( 'pixova_setup' ) ) {
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function pixova_setup() {


    /*
    * Using this feature you can set the maximum allowed width for any content in the theme, like oEmbeds and images added to posts.
    * @see http://codex.wordpress.org/Content_Width
    */
    if ( ! isset( $content_width ) ) {
        $content_width = 640;
    }

    /**
     * Widget importer
     */
        require get_template_directory() . '/inc/importer.php';

    /**
     * Custom template tags for this theme.
     */

        require get_template_directory() . '/inc/template-tags.php';


    /**
     * Custom functions that act independently of the theme templates.
     */

        require get_template_directory() . '/inc/extras.php';


    /**
     * Customizer additions.
     */

        require get_template_directory() . '/inc/customizer.php';
        require get_template_directory() . '/inc/custom-controls.php';
        require get_template_directory() . '/inc/custom-header.php';

    /**
     * Sidebars
     */
    
        require get_template_directory() . '/sidebars/sidebars.php';

    /**
     * Widgets
     */
    
        require get_template_directory() . '/widgets/widget-about-sm.php';
        require get_template_directory() . '/widgets/widget-social-icons.php';
        require get_template_directory() . '/widgets/widget-latest-posts.php';
        require get_template_directory() . '/widgets/widget-flickr.php';

    /**
     * PLugins
     */
    require get_template_directory() . '/inc/plugin-activation.php';

    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     * If you're building a theme based on machoframe, use a find and replace
     * to change 'qck' to the name of your theme in all the template files
     */
       load_theme_textdomain( 'macho-lite', get_template_directory() . '/languages/' );

    // Add default posts and comments RSS feed links to head.
       add_theme_support( 'automatic-feed-links' );

    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
       add_theme_support( 'title-tag' );

    /*
     * Enable support for Post Thumbnails on posts and pages.
     *
     * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
     */
        add_theme_support( 'post-thumbnails', array( 'post', 'page') );

    // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'primary'   => __( 'Header Menu', 'macho-lite' ),
            'secondary' => __( 'Footer Menu', 'macho-lite' )
        ) );

  // Setup the WordPress core custom background feature.
      add_theme_support( 'custom-background', apply_filters( 'pixova_custom_background_args', array(
        'default-color' => 'ffffff',
        'default-image' => '',
      ) ) );

  // WooCommerce Support
     add_theme_support( 'woocommerce' );

    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
        add_theme_support( 'html5', array(
            'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
        ) );


    /*
     * Add image sizes
     * @link http://codex.wordpress.org/Function_Reference/add_image_size
     */
        add_image_size('small-testimonial-image', 82, 82, true);
        add_image_size('portfolio-widget', 70, 70, true);
        add_image_size('project-slider-main-image', 270, 426, true);
        add_image_size('project-slider-logo-image', 187, 35, true);
        add_image_size('homepage-blog-posts', 250, 250, true);
        add_image_size('team-member', 200, 222, true);


    } // function pixova_setup

    add_action( 'after_setup_theme', 'pixova_setup', 9 );

} // function exists (pixova_setup) check


/**
 * Enqueue scripts and styles.
 *
 * @link http://codex.wordpress.org/Plugin_API/Action_Reference/wp_enqueue_scripts
 */

if(!function_exists( 'pixova_scripts' ) ) {

    function pixova_scripts() {
      
        // Bootstrap JS (required for theme & shortcodes)
        wp_register_script( 'bootstrap-min-js' , MT_THEME_URL . '/layout/js/bootstrap/bootstrap.min.js', array('jquery'), '3.3.4', true);

        // Query Loader 2
        wp_register_script( 'query-loader-js', MT_THEME_URL . '/layout/js/queryloader/queryloader2.min.js', array('jquery'), '2.0', true );

         // owlCarousel main JS
        wp_register_script( 'owlCarousel-js', MT_THEME_URL .'/layout/js/owl-carousel/owl.carousel.min.js', array('jquery'), '1.3.3', true);

        // Classie JS
        wp_register_script ('classie-js', MT_THEME_URL . '/layout/js/classie/classie.js', array('jquery'), '1.0.0', true );

        // Smooth Scroll JS
        wp_register_script ( 'smooth-scroll-js', MT_THEME_URL . '/layout/js/smoothscroll/smoothscroll.js', array('jquery'), '0.9.9', true);

        // WOW js
        wp_register_script( 'wow-min-js', MT_THEME_URL . '/layout/js/wow/wow.min.js', array('jquery'), '1.0.3', true);

        // Simple Placeholders JS
        wp_register_script( 'simple-placeholder-js', MT_THEME_URL . '/layout/js/simpleplaceholder/simplePlaceholder.js', array('jquery'), '1.0.0', true );

        // jQuery Easy Pie Charts
        wp_register_script( 'pie-chart-js', MT_THEME_URL . '/layout/js/easypiechart/jquery.easypiechart.min.js', array('jquery'), '2.1.7', true );

        // Scripts JS
        wp_register_script ( 'scripts-js', MT_THEME_URL . '/layout/js/scripts.js', array('jquery', 'classie-js'), '1.0', true );

        // Preloader JS
        wp_register_script( 'preloader-js', MT_THEME_URL . '/layout/js/preloader.js', array('query-loader-js'), '1.0', true );

        // Plugins JS
        wp_register_script( 'plugins-js', MT_THEME_URL . '/layout/js/plugins.js', array('jquery', 'pie-chart-js', 'wow-min-js', 'scripts-js', 'simple-placeholder-js'), '1.0', true );

        
        // enqueue scripts
        wp_enqueue_script( 'query-loader-js' );
        wp_enqueue_script( 'jquery' );
        wp_enqueue_script( 'bootstrap-min-js' );
        wp_enqueue_script( 'owlCarousel-js' );
        wp_enqueue_script( 'classie-js' );
        wp_enqueue_script( 'simple-placeholder-js' );



        
        if( isset($options['smoth-scroll-enable'] ) && $options['smoth-scroll-enable'] == 1 ) // smoth scroll is enabled
            {   wp_enqueue_script( 'smooth-scroll-js' ); } 

         if( isset($options['animations-enable'] ) && $options['animations-enable'] == 1 ) // animations are enabled
            {   wp_enqueue_script( 'wow-min-js' ); }     
        
        wp_enqueue_script( 'scripts-js' );
        wp_enqueue_script( 'plugins-js' );
        wp_enqueue_script( 'preloader-js' );

        /**
         *
         * Stylesheets below
         *
         */

        // General theme Stylesheet
        wp_enqueue_style( 'pixova-style', get_stylesheet_uri() );

        // Animate CSS
        wp_enqueue_style( 'animate-css', MT_THEME_URL .'/layout/css/animate.css');

        // Font Awesome Stylesheet
        wp_enqueue_style ( 'font-awesome-css', MT_THEME_URL . '/layout/css/font-awesome.min.css');

        // Google Fonts StyleSheet
        wp_enqueue_style( 'ga-fonts', 'http://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,600,700|Oxygen:400,700' );

        // Animate CSS
         if( isset($options['animations-enable'] ) && $options['animations-enable'] == 1 ) // animations are enabled
            {   wp_enqueue_style( 'animate-css', MT_THEME_URL . '/layout/css/animate.css'); }     
       
        // Pretty Photo CSS
        wp_enqueue_style( 'prettyPhoto-css', MT_THEME_URL . '/layout/css/prettyPhoto.css' );

        // Bootstrap Stylesheet
        wp_enqueue_style('bootstrap-min-css', MT_THEME_URL . '/layout/css/bootstrap.min.css');
       


        // owlCarousel Stylesheet
        wp_enqueue_style( 'owlCarousel-main-css', MT_THEME_URL .'/layout/css/owl.carousel.css' );
        wp_enqueue_style( 'owlCarousel-theme-css', MT_THEME_URL .'/layout/css/owl.theme.css' );
        wp_enqueue_style( 'owlCarousel-transitions-css', MT_THEME_URL .'/layout/css/owl.transitions.css' );

    } // function pixova_scripts end

    add_action( 'wp_enqueue_scripts', 'pixova_scripts' );

} // function exists (pixova_scripts) check


/**
 * Function that only loads the comment-reply JS script on pages that have the comment form enabled
 *
 * Given that we have a one page website, is_singular() will return true for pages as well (that means it gets loaded on the homepage for nothing)
 *
 */
function mt_comment_reply_js() {
 
 if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
        }
  }
add_action( 'comment_form_before', 'mt_comment_reply_js' );


if( !function_exists( 'mt_import_options' ) ) {
    
/**
 * Sets up theme menus and options.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
    function mt_import_options() {



            // new pages to be created
            $new_pages = array('Homepage', 'Blog');

            foreach($new_pages as $new_page_title) {

                //don't change the code bellow, unless you know what you're doing

                $page_check = get_page_by_title($new_page_title);

                $new_page = array(
                    'post_type' => 'page',
                    'post_title' => $new_page_title,
                    'post_status' => 'publish',
                    'post_author' => 1,
                );

                if(!isset($page_check->ID)){
                    $new_page_id = wp_insert_post($new_page);
                }
            }


            // Start creating the menus & reading options
            $homepage = get_page_by_title('Homepage');
            $blog_page = get_page_by_title('Blog');

            // update reading options to newly created pages
            update_option('show_on_front', 'page');
            update_option('page_on_front', $homepage->ID);
            update_option('page_for_posts', $blog_page->ID);

            // create the nav menus and insert items into them (all sections will be defaultly linked in the menu)
            $menuname = MT_THEME_NAME . ' Main Menu';
            $mtmenulocation = 'primary';

            // Does the menu exist already?
            $menu_exists = wp_get_nav_menu_object( $menuname );

            // If it doesn't exist, let's create it.
            if( !$menu_exists ) {

                $menu_id = wp_create_nav_menu($menuname);

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('About', 'macho-lite'),
                        'menu-item-url' => home_url( '/#about', 'macho-lite'), 
                        'menu-item-status' => 'publish'
                    )
                );

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('Recent work', 'macho-lite'),
                        'menu-item-url' => home_url( '/#works' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('Testimonials', 'macho-lite'),
                        'menu-item-url' => home_url( '/#testimonials' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('Team', 'macho-lite'),
                        'menu-item-url' => home_url( '/#team' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('News', 'macho-lite'),
                        'menu-item-url' => home_url( '/#news' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                 wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('Contact', 'macho-lite'),
                        'menu-item-url' => home_url( '/#contact' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                // Grab the theme locations and assign our newly-created menu
                if( !has_nav_menu( $mtmenulocation ) ){
                    $locations = get_theme_mod('nav_menu_locations');
                    $locations[$mtmenulocation] = $menu_id;
                    set_theme_mod( 'nav_menu_locations', $locations );
                }
            }

             // create the nav menus and insert items into them (all sections will be defaultly linked in the menu)
            $menuname = MT_THEME_NAME . ' Footer Menu';
            $mtmenulocation = 'secondary';

            // Does the menu exist already?
            $menu_exists = wp_get_nav_menu_object( $menuname );

            // If it doesn't exist, let's create it.
            if( !$menu_exists ) {

                $menu_id = wp_create_nav_menu($menuname);

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('About us', 'macho-lite'),
                        'menu-item-url' => home_url( '/', 'macho-lite'), 
                        'menu-item-status' => 'publish'
                    )
                );

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('Docs & Fax', 'macho-lite'),
                        'menu-item-url' => home_url( '/' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('Link to article', 'macho-lite'),
                        'menu-item-url' => home_url( '/' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('Frequently asked', 'macho-lite'),
                        'menu-item-url' => home_url( '/' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('News', 'macho-lite'),
                        'menu-item-url' => home_url( '/#news' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                 wp_update_nav_menu_item($menu_id, 0, 
                    array(
                        'menu-item-title' =>  __('Contact', 'macho-lite'),
                        'menu-item-url' => home_url( '/#contact' ), 
                        'menu-item-status' => 'publish'
                    )
                );

                // Grab the theme locations and assign our newly-created menu
                if( !has_nav_menu( $mtmenulocation ) ){
                    $locations = get_theme_mod('nav_menu_locations');
                    $locations[$mtmenulocation] = $menu_id;
                    set_theme_mod( 'nav_menu_locations', $locations );
                }
            }


            unregister_widget('WP_Widget_Pages');
            unregister_widget('WP_Widget_Calendar');
            unregister_widget('WP_Widget_Archives');
            unregister_widget('WP_Widget_Links');
            unregister_widget('WP_Widget_Meta');
            unregister_widget('WP_Widget_Search');
            unregister_widget('WP_Widget_Text');
            unregister_widget('WP_Widget_Categories');
            unregister_widget('WP_Widget_Recent_Posts');
            unregister_widget('WP_Widget_Recent_Comments');
            unregister_widget('WP_Widget_RSS');
            unregister_widget('WP_Widget_Tag_Cloud');


    } // function mt_import_options end
} // function exists  (mt_import_options) check
add_action('after_setup_theme', 'mt_import_options');

if( !function_exists( 'mt_import_widgets' ) ) { 
/**
 * Sets up theme widgets like in the demo.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. 
 */
function mt_import_widgets() {

        $run = 0;

        // run this puppy onle once 
        if($run == 1 ) {
            return;
        } else {
        // new widget importer class instance 
            $widget_importer = new Macho_Widget_Importer();
            $widget_importer->process_imports();
            $run = 1;
        }

    } // function mt_theme_custom_activation
} // function exists (mt_import_widgets) check
add_action('widgets_init', 'mt_import_widgets', 99999);


add_action( 'tgmpa_register', 'mt_register_required_plugins' );

function mt_register_required_plugins() {

    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(

        // This is an example of how to include a plugin pre-packaged with a theme.
        array(
            'name'               => 'Contact Form 7', // The plugin name.
            'slug'               => 'contact-form-7', // The plugin slug (typically the folder name).
            'source'             => get_template_directory() . '/plugins/contact-form-7.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
            'version'            => '4.2', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            'force_activation'   => true, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url'       => '', // If set, overrides default API URL and points to an external URL.
        ),
    );

    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'mt-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => false,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => __( 'Install Required Plugins', 'macho-lite' ),
            'menu_title'                      => __( 'Install Plugins', 'macho-lite' ),
            'installing'                      => __( 'Installing Plugin: %s', 'macho-lite' ), // %s = plugin name.
            'oops'                            => __( 'Something went wrong with the plugin API.', 'macho-lite' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins' ),
            'return'                          => __( 'Return to Required Plugins Installer', 'macho-lite' ),
            'plugin_activated'                => __( 'Plugin activated successfully.', 'macho-lite' ),
            'complete'                        => __( 'All plugins installed and activated successfully. %s', 'macho-lite' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

    tgmpa( $plugins, $config );

}