<?php

if(!defined('ABSPATH')){
  die(); // no direct access
}

if ( !class_exists('WP_Customize_Control') ) {
  return null;
}

/**
* A class to create a dropdown for all categories in your wordpress site
*/
class Category_Dropdown_Custom_Control extends WP_Customize_Control {

  private $cats = false;
  public $type = 'category-dropdown';

  public function __construct($manager, $id, $args = array(), $options = array()) {
      $this->cats = get_categories($options);
      parent:__construct($manager, $id, $args);
  }

  public function render_content() { if(!empty($this->cats)) { ?>

      <label>
      <span class="customize-category-select-control"><?php echo esc_html($this->label); ?></span>
      <select <?php $this->link();
      ?>>

      <?php

      foreach ($this->cats as $cat) {
        printf('<option value="%s"%s>%s</option>', $cat->term_id, selected($this->value(), $cat->term_id, false), $cat->name);
      }

      ?>

      </select>
      </label>

    <?php }
  }
}


/**
 * Customize for textarea, extend the WP customizer
 *
 */

class Textarea_Custom_Control extends WP_Customize_Control
{

  public $type = 'textarea';
  public function render_content() {
    ?>
    <label>
      <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
      <textarea class="large-text" cols="20" rows="5" <?php $this->link(); ?>>
        <?php echo esc_textarea( $this->value() ); ?>
      </textarea>
    </label>
    <?php
  }
}


/**
 * Class to create a custom tags control
 */
class Text_Editor_Custom_Control extends WP_Customize_Control
{
      public $type = 'text-editor';
      public function render_content()
       {
            ?>
                <label>
                  <span class="customize-text_editor"><?php echo esc_html( $this->label ); ?></span>
                  <?php
                    $settings = array(
                      'textarea_name' => $this->id,
                      'media_buttons' => false,
                      );
                    wp_editor($this->value(), $this->id, $settings );
                  ?>
                </label>
            <?php
       }
}

class Number_Custom_Control extends WP_Customize_Control {

    public $type = 'number';
    public function render_content() {
    ?>
      <label>
        <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
        <input type="number" <?php $this->link(); ?> value="<?php echo intval( $this->value() ); ?>" />
      </label>
    <?php
    }
  }

    class MT_Theme_Support extends WP_Customize_Control
  {
    public function render_content()
    {
      $url = 'http://www.machothemes.com/themes/pixova/';
      $link = sprintf( wp_kses( __( 'Check out the <a href="%s">PRO version</a> for full control over the frontpage.', 'pixova-lite' ), array(  'a' => array( 'href' => array() ) ) ), esc_url( $url ) );
      echo $link;


    }
  }

  class MT_Theme_Support_Googlemap extends WP_Customize_Control
  {
    public function render_content()
    {
      $url = 'http://www.machothemes.com/themes/pixova/';
      $link = sprintf( wp_kses( __( 'Check out the <a href="%s">PRO version</a> for unlimited Google Maps', 'pixova-lite' ), array(  'a' => array( 'href' => array() ) ) ), esc_url( $url ) );
      echo $link;
    }
  }

  class MT_Theme_Support_Pricing extends WP_Customize_Control
  {
    public function render_content()
    {
      $url = 'http://www.machothemes.com/themes/pixova/';
      $link = sprintf( wp_kses( __( 'Check out the <a href="%s">PRO version</a> for unlimited Pricing Tables', 'pixova-lite' ), array(  'a' => array( 'href' => array() ) ) ), esc_url( $url ) );
      echo $link;
    }
  }

  class CF7_Custom_Control extends WP_Customize_Control{


      public function get_cf7_forms(){

        include_once(ABSPATH . 'wp-admin/includes/plugin.php');

        global $wpdb;

        // no more php warnings
        $contact_forms = array();

        // check if CF7 is activated
        if (is_plugin_active('contact-form-7/wp-contact-form-7.php')) {


            $cf7 = $wpdb->get_results( "SELECT ID, post_title FROM $wpdb->posts WHERE post_type = 'wpcf7_contact_form' ");
            if ($cf7) {

                foreach ( $cf7 as $cform ) {
                    $contact_forms[$cform->post_title] .= $cform->ID;
                }
            } else {
                $contact_forms["No contact forms found"] = 0;
            }

        }

      return $contact_forms;
    }


    public function render_content() {
    ?>
     <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
      <select <?php $this->link(); ?> style="width:100%;">

          <?php

          $MT_contact_forms = $this->get_cf7_forms();
          echo '<option selected="selected" value="default">-- Select your contact form -- </option>';

          foreach($MT_contact_forms as $form_title => $form_id ){
              echo '<option value="'.$form_id.'" >'.$form_title.'</option>';
          }

          ?>
      </select>
    <?php
    }
}
